.. pandas-msgpack documentation master file, created by
   sphinx-quickstart on Wed Feb  8 10:52:12 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pandas-msgpack's documentation!
==========================================

The :mod:`pandas_msgpack` module provides an interface from `pandas https://pandas.pydata.org`
to the `msgpack <http://msgpack.org/index.html>`__ library. This is a lightweight portable
binary format, similar to binary JSON, that is highly space efficient, and provides good performance
both on the writing (serialization), and reading (deserialization).

 Contents:

.. toctree::
   :maxdepth: 2

   install.rst
   tutorial.rst
   compression.rst
   read_write.rst
   api.rst
   changelog.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
